lektor-brunch-support
=====================

.. image:: https://img.shields.io/pypi/v/lektor-brunch-support.svg?maxAge=2592000
   :target: https://pypi.python.org/pypi/lektor-brunch-support

This is a plugin for Lektor that adds support for `Brunch <http://brunch.io/>`__
to projects.

When enabled it can build a Brunch project located in the brunch/ folder into
the asset folder automatically when the server (or build process) is run.

Enabling the Plugin
-------------------

.. code:: ini

  [packages]
  lektor-brunch-support = 0.1.0
